!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
!		The Von Karman swirling flow
!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
 SUBROUTINE FUNC(NDIM,U,ICP,PAR,IJAC,F,DFDU,DFDP)
!---------- ----

 IMPLICIT NONE
 INTEGER, INTENT(IN) :: NDIM, ICP(*), IJAC
 DOUBLE PRECISION, INTENT(IN) :: U(NDIM), PAR(*)
 DOUBLE PRECISION, INTENT(OUT) :: F(NDIM)
 DOUBLE PRECISION, INTENT(INOUT) :: DFDU(NDIM,NDIM), DFDP(NDIM,*)

 DOUBLE PRECISION U1, U2, U3, U4, U5, gamma, zinf

   U1 = U(1)
   U2 = U(2)
   U3 = U(3)
   U4 = U(4)
   U5 = U(5)

   gamma = PAR(1)
   zinf   = PAR(3)

   F(1) = zinf*U2
   F(2) = zinf*U3
   F(3) = zinf*( - 2*gamma*U4 + U2*U2 - 2*U1*U3 - U4*U4)
   F(4) = zinf*U5
   F(5) = zinf*(2*gamma*U2 + 2*U2*U4 - 2*U1*U5)

 END SUBROUTINE FUNC
!---------------------------------------------------------------------- 

 SUBROUTINE STPNT(NDIM,U,PAR,T)
!---------- -----

 IMPLICIT NONE
 INTEGER, INTENT(IN) :: NDIM
 DOUBLE PRECISION, INTENT(INOUT) :: U(NDIM),PAR(*)
 DOUBLE PRECISION, INTENT(IN) :: T

 DOUBLE PRECISION gamma,finf,zinf

   gamma = 1.
   finf  = 0.
   zinf  = 500.

   PAR(1) = gamma 
   PAR(2) =-finf
   PAR(3) = zinf

   U(1) = 0.
   U(2) = 0.
   U(3) = 0.
   U(4) = 0.
   U(5) = 0.

 END SUBROUTINE STPNT
!---------------------------------------------------------------------- 

 SUBROUTINE BCND(NDIM,PAR,ICP,NBC,U0,U1,F,IJAC,DBC)
!---------- ----

 IMPLICIT NONE
 INTEGER, INTENT(IN) :: NDIM, ICP(*), NBC, IJAC
 DOUBLE PRECISION, INTENT(IN) :: PAR(*), U0(NDIM), U1(NDIM)
 DOUBLE PRECISION, INTENT(OUT) :: F(NBC)
 DOUBLE PRECISION, INTENT(INOUT) :: DBC(NBC,*)

 DOUBLE PRECISION gamma,finf,C,A,B

   gamma = PAR(1)
   finf  =-PAR(2)

   C = DSQRT(finf**4 + 4*gamma**2)
   A = DSQRT(C + finf**2) / DSQRT(2.d0)
   B = DSQRT(C - finf**2) / DSQRT(2.d0)

   F(1) = U0(1)
   F(2) = U0(2)
   F(3) = U0(4)-1+gamma
   F(4) = (finf+A)*U1(2) + U1(3) - gamma*U1(4)/A
   F(5) = A*B**2*U1(2)/gamma + (finf+A)*U1(4) + U1(5)
   F(6) = U1(1)-finf

 END SUBROUTINE BCND
!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
 SUBROUTINE ICND
 END SUBROUTINE ICND

 SUBROUTINE FOPT
 END SUBROUTINE FOPT

 SUBROUTINE PVLS
 END SUBROUTINE PVLS
!---------------------------------------------------------------------- 
!---------------------------------------------------------------------- 
